summaryrefslogtreecommitdiff
path: root/cmake
diff options
context:
space:
mode:
Diffstat (limited to 'cmake')
-rw-r--r--cmake/FindGLU.cmake14
-rw-r--r--cmake/FindZIP.cmake46
2 files changed, 23 insertions, 37 deletions
diff --git a/cmake/FindGLU.cmake b/cmake/FindGLU.cmake
deleted file mode 100644
index fa56a51..0000000
--- a/cmake/FindGLU.cmake
+++ /dev/null
@@ -1,14 +0,0 @@
-
-
-# Use of this file is deprecated, and is here for backwards compatibility with CMake 1.4
-# GLU library is now found by FindOpenGL.cmake
-#
-#
-
-INCLUDE(FindOpenGL)
-
-IF (OPENGL_GLU_FOUND)
- SET (GLU_LIBRARY ${OPENGL_LIBRARIES})
- SET (GLU_INCLUDE_PATH ${OPENGL_INCLUDE_DIR})
-ENDIF (OPENGL_GLU_FOUND)
-
diff --git a/cmake/FindZIP.cmake b/cmake/FindZIP.cmake
index 0bbdce4..fd3ae7d 100644
--- a/cmake/FindZIP.cmake
+++ b/cmake/FindZIP.cmake
@@ -1,34 +1,34 @@
-# - Find zzip
-# Find the native ZZIP includes and library
+# - Find zip
+# Find the native ZIP includes and library
#
-# ZZIP_INCLUDE_DIR - where to find zzip.h, etc.
-# ZZIP_LIBRARIES - List of libraries when using zzip.
-# ZZIP_FOUND - True if zzip found.
+# ZIP_INCLUDE_DIR - where to find zzip.h, etc.
+# ZIP_LIBRARIES - List of libraries when using zzip.
+# ZIP_FOUND - True if zzip found.
-IF (ZZIP_INCLUDE_DIR)
+IF (ZIP_INCLUDE_DIR)
# Already in cache, be silent
- SET(ZZIP_FIND_QUIETLY TRUE)
-ENDIF (ZZIP_INCLUDE_DIR)
+ SET(ZIP_FIND_QUIETLY TRUE)
+ENDIF (ZIP_INCLUDE_DIR)
-FIND_PATH(ZZIP_INCLUDE_DIR zip.h)
+FIND_PATH(ZIP_INCLUDE_DIR zip.h)
-SET(ZZIP_NAMES zip)
-FIND_LIBRARY(ZZIP_LIBRARY NAMES ${ZZIP_NAMES} )
+SET(ZIP_NAMES zip)
+FIND_LIBRARY(ZIP_LIBRARY NAMES ${ZZIP_NAMES} )
-# handle the QUIETLY and REQUIRED arguments and set ZZIP_FOUND to TRUE if
+# handle the QUIETLY and REQUIRED arguments and set ZIP_FOUND to TRUE if
# all listed variables are TRUE
INCLUDE(FindPackageHandleStandardArgs)
-FIND_PACKAGE_HANDLE_STANDARD_ARGS(ZZIP DEFAULT_MSG ZZIP_LIBRARY ZZIP_INCLUDE_DIR)
+FIND_PACKAGE_HANDLE_STANDARD_ARGS(ZIP DEFAULT_MSG ZIP_LIBRARY ZIP_INCLUDE_DIR)
-IF(ZZIP_FOUND)
- SET( ZZIP_LIBRARIES ${ZZIP_LIBRARY} )
-ELSE(ZZIP_FOUND)
- SET(ZZIP_FOUND FALSE)
- IF (ZZIP_REQUIRED)
- MESSAGE(FATAL_ERROR "zziplib not found")
- ENDIF (ZZIP_REQUIRED)
- SET( ZZIP_LIBRARIES )
-ENDIF(ZZIP_FOUND)
+IF(ZIP_FOUND)
+ SET( ZIP_LIBRARIES ${ZZIP_LIBRARY} )
+ELSE(ZIP_FOUND)
+ SET(ZIP_FOUND FALSE)
+ IF (ZIP_REQUIRED)
+ MESSAGE(FATAL_ERROR "libzip not found")
+ ENDIF (ZIP_REQUIRED)
+ SET( ZIP_LIBRARIES )
+ENDIF(ZIP_FOUND)
-MARK_AS_ADVANCED( ZZIP_LIBRARY ZZIP_INCLUDE_DIR )
+MARK_AS_ADVANCED( ZIP_LIBRARY ZIP_INCLUDE_DIR )